darkhistory.utilities.log_series_diff — DarkHistory documentation

# darkhistory.utilities.log_series_diff

`darkhistory.utilities.` `log_series_diff`(b, a)

  The Taylor series for log(1+b) - log(1+a).

  Parameters: | a : ndarray Input for log(1+a). b : ndarray Input for log(1+b).
  Returns: | ndarray The Taylor series log(1+b) - log(1+a), up to the 11th order term.

#### Previous topic

darkhistory.utilities.log_1_plus_x

#### Next topic

darkhistory.utilities.spence_series_diff

### This Page

Show Source